@@ -52,7 +52,7 @@ module.exports=function(app){
             console.log(x);
             app.use(express.static(work_dir+'/public'));
             app.use(function (req, res, next) {
-                    if(res.status(404)) {
+                   // if(res.status(404)) {
 
                     var url = URL.parse(req.url, true).pathname ;
                     if(url.indexOf('api')<0 && url.indexOf('.')<0){
@@ -61,9 +61,9 @@ module.exports=function(app){
                     }else{
                         next();
                     }
-                    }else{
-                        next();
-                    }
+                   // }else{
+                    //    next();
+                   // }
             });
         });
 }
\ No newline at end of file
