@@ -11,14 +11,29 @@
 
 const fs=require('fs');
 const cluster = require('cluster');
+var w;
 
 const addWatcher=function (path){
 
      fs.watch(path, {encoding: 'buffer'}, (eventType, filename) => {
+            //console.log(eventType +'-'+filename);
             console.log(filename + " is changed  try to restart server ..");
+            if(eventType=='rename'){
+                  fs.stat(path +"/"+ filename, function(err, stats) {
+                         if (!err) {
+                            if(stats.isDirectory()){
+                               // console.log('add watcher'+eventType +'-'+filename);
+                                addWatcher(path+"/"+filename);
+                            }
+                         }
+                  });
+            }
             Object.keys(cluster.workers).forEach((id) => {
                 cluster.workers[id].process.kill();
             });
+
+           // fs.unwatch(path);
+
     });
 
     fs.readdir(path, function(err, files) { 
